<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AppItem</name>
    <message>
        <source>Move to Trash</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dock::AppItem</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Retirer du dock</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Ajouter au dock</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Forcer à quitter</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tout fermer</translation>
    </message>
</context>
<context>
    <name>dock::DockGlobalElementModel</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Undock</source>
        <translation>Retirer du dock</translation>
    </message>
    <message>
        <source>Dock</source>
        <translation>Ajouter au dock</translation>
    </message>
    <message>
        <source>Force Quit</source>
        <translation>Forcer à quitter</translation>
    </message>
    <message>
        <source>Close All</source>
        <translation>Tout fermer</translation>
    </message>
</context>
<context>
    <name>dock::TaskManager</name>
    <message>
        <source>%1 files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
